@@ -325,8 +325,8 @@ def delete_department_user_map(organization_id: int, department_id: int, user_id
     :param user_ids:
     :return:
     """
-    department_instance = Department.objects.filter(organization_id=organization_id, pk=department_id).first()
-    if not department_instance.exists():
+    department_instance = Department.objects.get(organization_id=organization_id, pk=department_id)
+    if not department_instance:
         return Resp(code=BadRequestCode, msg="当前组织没有该部门")
     if not department_instance.path:
         path = [department_instance.id]
