@@ -115,16 +115,16 @@ class DepartmentViewSet(object):
         return get_user_departments(self.organization_id, user_id)
 
     # def department_user_list(self, department_id: int, page: int = 1, size: int = 20):
-    def department_user_list(self, department_id: int, page: int = 1, size: int = 20):
+    def department_user_list(self, department_ids: list, page: int = 1, size: int = 20):
         """
         通过部门获取部门下的用户
-        :param department_id: 部门id
+        :param department_ids: 部门id列表
         :param page: 页码
         :param size: 每页数量
         :return:
         """
         # return get_department_user(self.organization_id, department_id, page, size)
-        return get_department_user(self.organization_id, department_id)
+        return get_department_user(self.organization_id, department_ids)
 
     def create_department_user(self, department_id: int, user_ids: list):
         """
